# Azure Blob Explorer for Python

## Instillation

Using PIP

```bash
pip install azblobexplorer
```

Using source

```bash
python setup.py install
```

## Usage

Please see the documentation at [https://akshaybabloo.github.io/azure-blob-explorer-python/](https://akshaybabloo.github.io/azure-blob-explorer-python/)

## Contributions

All contributions are welcome.
